---
title: <span class="badge builder"></span> TooltipOptions
---
# <span class="badge builder"></span> TooltipOptions

## Constructor

```python
TooltipOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> geomap.TooltipOptions
```

### <span class="badge object-method"></span> mode

```python
def mode(mode: geomap.TooltipMode) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [TooltipOptions](./object-TooltipOptions.md)
